#
# spec file for package projectlibre
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           projectlibre
Version:        1.9.3
Release:        3.1
Summary:        Project Management Tool
License:        CPAL-1.0
Group:          Productivity/Office/Management
URL:            https://www.projectlibre.org
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        %{name}.png
Source3:        x-%{name}.desktop
Patch0:         %{name}-nosourcetarget.patch
BuildRequires:  ant
BuildRequires:  java-devel >= 1.8
BuildRequires:  update-desktop-files
Requires:       java >= 1.8
BuildArch:      noarch

%description
ProjectLibre is a project manager which is compatible with Microsoft
Project 2003, 2007 and 2010 files. It has Gantt charts, PERT charts,
network diagrams and Earned Value Costing.

%prep
%autosetup -p1

%build
#Set the file encoding for source files
export JAVA_TOOL_OPTIONS=-Dfile.encoding=cp1252
cd projectlibre_build/
%{ant} clean
%{ant} -Dant.build.javac.source=1.8 -Dant.build.javac.target=1.8

%install
export NO_BRP_CHECK_BYTECODE_VERSION=true
mkdir -p %{buildroot}%{_datadir}/%{name}/lib
install -Dm0755 projectlibre_contrib/*.jar %{buildroot}%{_datadir}/%{name}/lib/
install -Dm0755 projectlibre_build/dist/%{name}.jar %{buildroot}%{_datadir}/%{name}/

# startscript
cat > %{name} << EOF
#!/bin/sh
#
echo Starting %{name} version %{version} ...
echo with options : \${@}

java -jar %{_datadir}/%{name}/%{name}.jar \${@}

EOF

# Install startscript
install -Dm0755 %{name} %{buildroot}%{_bindir}/%{name}

# Install desktop file and icon with -i switch ;)
%suse_update_desktop_file -i %{name}

%files
%license projectlibre_build/license/*
%doc projectlibre_build/doc/*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*

%changelog
* Tue Feb 20 2024 Christophe Marin <christophe@krop.fr>
- Switch from %%patchN to %%autosetup
* Fri Apr  8 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
  * fixes build in Factory with jdk17
- Added patch:
  * projectlibre-nosourcetarget.patch
    + Do not hardcore java source and target levels in the build.xml
    files. Allow them to be specified from ant command-line
* Tue Feb  2 2021 Axel Braun <axel.braun@gmx.de>
- version 1.9.3 - no changelog
  revert spec file to earlier version using ant build
  ran spec-cleaner on it
* Mon Jul  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.9.2. No changelog.
- Spec cleanup
* Sat Apr 20 2019 Axel Braun <axel.braun@gmx.de>
- version 1.9.1
  various bugfixes and improvements
  translations added
* Thu Jun 14 2018 axel.braun@gmx.de
- version 1.8.0
  build.diff removed
* Sat Nov 11 2017 axel.braun@gmx.de
- build.diff: Shift build version to 1.6 (TW build failure)
  Set explicit file encoding  to cp1252
* Wed Jun 28 2017 jengelh@inai.de
- Rewrite description according to openSUSE guidelines.
* Sun May 28 2017 axel.braun@gmx.de
- implemented source service to pull from git
* Sun May  7 2017 axel.braun@gmx.de
- changes for build from source
  using an export from github
* Thu May  4 2017 axel.braun@gmx.de
- Update to version 1.7.0
* Wed Sep 16 2015 ronisbr@gmail.com
- Update to version 1.6.2.
  * No changelog available.
* Sat Aug  1 2015 ronisbr@gmail.com
- Update .spec file.
  * Update header information;
  * Remove unneeded build dependencies.
- Remove readme-src-archive-create file.
- Update to version 1.6.1.
  * No changelog available.
* Fri Mar 22 2013 jw@suse.com
- huch, broken specfile fixed.
* Fri Dec 14 2012 lumnis@opensuse.org
- updated to version 1.5.2
* Sun Oct 21 2012 lumnis@opensuse.org
- initial project setup
